//
//  HealthManager.swift
//  Weight
//
//  Created by Matthew Newill on 27/04/2017.
//  Copyright © 2017 DevFright.com. All rights reserved.
//

import Foundation
import HealthKit

class HealthManager {
    public let healthStore = HKHealthStore()
    
    public func requestPermissions() {
        let readDataTypes : Set = [HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMass)!]
        
        healthStore.requestAuthorization(toShare: nil, read: readDataTypes, completion: { (success, error) in
            if success {
                print("Authorization complete")
                self.fetchWeightData()
            } else {
                print("Authorization error: \(String(describing: error?.localizedDescription))")
            }
        })
        
    }
    
    func fetchWeightData() {
        print("Fetching weight data")
        
        let quantityType : Set = [HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMass)!]
        
        //Fetch the last 7 days of bodymass.

        let startDate = Date.init(timeIntervalSinceNow: -7*24*60*60)
        let endDate = Date()

        let predicate = HKQuery.predicateForSamples(withStart: startDate,
                                                    end: endDate,
                                                    options: .strictStartDate)
        
        let sampleQuery = HKSampleQuery.init(sampleType: quantityType.first!,
                                             predicate: predicate,
                                             limit: HKObjectQueryNoLimit,
                                             sortDescriptors: nil,
                                             resultsHandler: { (query, results, error) in
                                                DispatchQueue.main.async(execute: {
                                                    NotificationCenter.default.post(name: NSNotification.Name(rawValue: "BodyMassDataAvailable"),
                                                                                    object: results as! [HKQuantitySample],
                                                                                    userInfo: nil)
                                                })
        })
        
        self.healthStore .execute(sampleQuery)

    }
}
